@@ -3,8 +3,6 @@ from powerml import CreateTopicsModel
 import nltk
 from nltk.stem import WordNetLemmatizer
 
-from math import ceil
-
 unblocked_human_unprompted_1gram_topics = [
     "SourceMarks",
     "VSCode",
@@ -63,24 +61,27 @@ class TopicGenerator(Generator):
         super().__init__([self.lemmatizer.lemmatize(topic.lower())
                           for topic in gold_topics])
 
-    def coverage_generator(self, messages, return_metrics=True):
-        model = CreateTopicsModel()
+    def _fit_and_predict(self, model, messages, _):
         model.fit(messages, 'one-word system components')
         generated_topics = [self.lemmatizer.lemmatize(
             topic.lower()) for topic in model.predict()]
-        metrics = self.compute_coverage(generated_topics)
-        coverage = metrics['Coverage']
-        rare_topics = metrics['Rare Types']
-        generated_messages = []
-        if rare_topics:
-            # generate at least 1 example per rare_topic, proportional to the amount of coverage of the messages
-            num_generate = ceil(
-                (1 - coverage) * len(messages) / len(rare_topics))
-            print(f'num generate: {num_generate}')
-            for topic in rare_topics:
-                modifier = f'include the topic \'{topic}\''
-                generated_messages.extend(self._generate_modified(
-                    messages, modifier, num_generate))
-        if return_metrics:
-            return generated_messages, metrics
-        return generated_messages
+        return generated_topics
+
+    def _get_modifier(self, topic):
+        return f'include the topic \'{topic}\''
+
+    def get_rare(self, messages, return_metrics=True):
+        """
+        Parameters
+        ----------
+        messages: list[str]
+            List of messages
+        return_metrics: bool
+            If True, return metrics
+
+        Returns
+        generated_data : The generated list of messages
+        metrics (optional): Metrics on data coverage before and after generating messages
+        -------
+        """
+        return super().get_rare(messages, return_metrics, CreateTopicsModel())
