@@ -1,8 +1,10 @@
 
+from typing import List
 from powerml import PowerML
 import logging
 import re
-from powerml.model.PowerML import MAX_TEMPLATE_TOKENS
+
+from powerml.utils.constants import MAX_TEMPLATE_TOKENS
 
 logger = logging.getLogger(__name__)
 
@@ -13,11 +15,10 @@ class ExtractTopicsModel:
     task done successfully and a list of topics.
     '''
 
-    def __init__(self, config={}, model_name=None):
-        self.model = PowerML(config)
-        self.model_name = "unblocked/extract-topics/v2"
+    def __init__(self, config={}, ):
+        self.model = PowerML(config, "unblocked/extract-topics/v2")
 
-    def fit(self, examples, topics: list[str]):
+    def fit(self, examples, topics: List[str]):
         self.examples = examples
         self.topics = topics
 
@@ -39,7 +40,7 @@ class ExtractTopicsModel:
             "{{topics}}": topic_string,
             "{{input}}": message,
         }
-        result = self.model.predict(prompt, model=self.model_name)
+        result = self.model.predict(prompt)
 
         return self.__post_process(result)
 
