@@ -28,8 +28,10 @@ class WriteEmailModel:
         subject : str
             The company for which the email is being generated.
         """
-        example_string = "\n\n".join(
-            [f"company: {example['subject']}\n\nemail: {example['email']}" for example in self.examples])
+        example_string = ''
+        if hasattr(self, 'examples'):
+            example_string = "\n\n".join(
+                [f"company: {example['subject']}\n\nemail: {example['email']}" for example in self.examples])
         prompt = {
             "{{examples}}": example_string,
             "{{input}}": subject
@@ -39,4 +41,7 @@ class WriteEmailModel:
             max_tokens=self.max_output_tokens,
             temperature=self.temperature,
         )
-        return output
+        return self.__post_process(output)
+
+    def __post_process(self, output):
+        return output.strip()
