@@ -173,8 +173,15 @@ def powerml_completions(params, url, key):
         url=url + "/v1/completions",
         headers=headers,
         json=params)
-    if response.status_code != 200:
+    if response.status_code == 429:
         raise requests.exceptions.RequestException
+    elif response.status_code != 200:
+        try:
+            description = response.json()
+        except BaseException:
+            description = response.status_code
+        finally:
+            raise Exception(f"API error {description}")
     return response
 
 
@@ -204,5 +211,13 @@ def powerml_train(params, url, key):
         url=url + "/v1/train",
         json=params)
     if response.status_code != 200:
-        raise requests.exceptions.HTTPError
+        try:
+            description = response.json()
+        except BaseException:
+            description = response.status_code
+        finally:
+            raise Exception(f"API error {description}")
+    description = response.json()
+    if 'model' not in description:
+        raise Exception(f"API error {description}")
     return response
